@@ -13,6 +13,8 @@ from os import walk
 import pandas as pd
 from pathlib import Path
 
+import decimal
+
 from tsfresh import extract_features
 from tsfresh.utilities.dataframe_functions import make_forecasting_frame
 from tsfresh.utilities.dataframe_functions import impute
@@ -36,23 +38,37 @@ def buildAdvancedPriceFeatures(quotes_df=None, lookback_window=20, rolling_direc
 
 
 class AbstractAssembler(ABC):
-    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', ts_features_pkl_file_name='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy',shortcut_features_saving_suffix='_shortcut_features.npy', shortcut_features_names_saving_suffix='_shortcut_features_names.npy',shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
+    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_suffix='_returns.pkl', features_pkl_file_suffix='_features.pkl', ts_features_pkl_file_suffix='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy',shortcut_features_saving_suffix='_shortcut_features.npy', shortcut_features_names_saving_suffix='_shortcut_features_names.npy',shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
         super().__init__()
         self.local_root_directory = local_root_directory
         self.user = user
-        self.features_pkl_file_name = features_pkl_file_name
+        self.features_pkl_file_suffix = features_pkl_file_suffix
+        self.returns_pkl_file_suffix = returns_pkl_file_suffix
+        self.ts_features_pkl_file_suffix = ts_features_pkl_file_suffix
+
         self.features_saving_suffix = features_saving_suffix
         self.features_names_saving_suffix = features_names_saving_suffix
-        self.returns_pkl_file_name = returns_pkl_file_name
+
         self.macro_features_directory = macro_features_directory
         self.shortcut_features_pkl_file_name = shortcut_features_pkl_file_name
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
         self.running_date=running_date
         self.starting_date=starting_date
         self.rolling_direction = rolling_direction
-        self.ts_features_pkl_file_name=ts_features_pkl_file_name
+
+        self.features_pkl_file_name = running_date.strftime('%d_%b_%Y')+features_pkl_file_suffix
+        self.returns_pkl_file_name = running_date.strftime('%d_%b_%Y')+returns_pkl_file_suffix
+        self.ts_features_pkl_file_name = running_date.strftime('%d_%b_%Y')+ts_features_pkl_file_suffix
+
         self.shortcut_features_saving_suffix = shortcut_features_saving_suffix
         self.shortcut_features_names_saving_suffix = shortcut_features_names_saving_suffix
+        self.backup_intermediary = True
+        self.short_feat_df_suffix = '_short_feat_df.pkl'
+        self.adv_feat_df_before_merge_suffix = '_adv_feat_before_merge_df.pkl'
+        self.adv_feat_df_raw_before_merge_suffix = '_adv_feat_raw_before_merge_df.pkl'
+        self.adv_feat_df_suffix = '_adv_feat_df.pkl'
+        self.ret_feat_df_suffix = '_ret_feat_df.pkl'
+        self.truncating_features = False
 
     @abstractmethod
     def assembleFeature(self, feature_type, n_past_features, tsfresh_lookback_window):
@@ -199,9 +215,15 @@ class FeaturesAssembler(AbstractAssembler):
     def preprocessFeatures(self):
 
         features = self.dbx.local_overwrite_and_load_pickle( folder='', subfolder=self.macro_features_directory, returns_pkl_file_name=self.features_pkl_file_name, local_root_directory = Path(self.local_root_directory))
+        if self.backup_intermediary :
+            adv_feat_df_name = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y') + self.adv_feat_df_raw_before_merge_suffix
+            print('saving '+adv_feat_df_name)
+            features.to_pickle(self.local_root_directory+adv_feat_df_name)
+
         features_names = [col for col in list(features.columns) if col!='Date']
         features['Date'] = pd.to_datetime(features['Date'])
 
+
         # MM 3 mois
         for col in features_names:
             features["MM63_{}".format(col)] = features[col] / features[col].shift(1).rolling(window=63).mean() - 1
@@ -231,8 +253,8 @@ class FeaturesAssembler(AbstractAssembler):
         for col in features_names:
             features[col] = features[col].pct_change().replace([np.inf, -np.inf], np.nan).fillna(0.)
 
-        for col in features_names:
-            features[col] = (features[col] - features[col].mean()) / features[col].std(ddof=0)
+#        for col in features_names:
+#            features[col] = (features[col] - features[col].mean()) / features[col].std(ddof=0)
 
         for col in features_names:
             features["quantile21_0_{}".format(col)] = features[col].rolling(window=20).quantile(0.)
@@ -265,8 +287,18 @@ class FeaturesAssembler(AbstractAssembler):
             features["mean_252_{}".format(col)] = features[col].rolling(window=252).mean()
 
         features_names = [col for col in list(features.columns) if col!='Date']
-        predictor_names = None
         features['Date'] = pd.to_datetime(features['Date'])
+        if self.truncating_features:
+            def decimal_truncate(x):
+                # By default rounding setting in python is decimal.ROUND_HALF_EVEN
+                # decimal.getcontext().rounding = decimal.ROUND_DOWN
+                c = decimal.Decimal(x)
+                return float(round(c, 2))
+
+            features = features.replace([np.inf, -np.inf], np.nan)
+            for col in features_names:
+                print('truncating '+col)
+                features[col] = features[col].copy().apply(decimal_truncate)
 
         return features , features_names
 
@@ -441,9 +473,7 @@ class FeaturesAssembler(AbstractAssembler):
         print('Max price date before filtering'+str(max(df_ret.index)))
         print('Min price date before filtering'+str(min(df_ret.index)))
 
-        advanced_features, advanced_features_names = self.preprocessFeatures()
-
-        features_names = [col for col in list(advanced_features.columns) if col!='Date']
+        advanced_features, features_names = self.preprocessFeatures()
 
         max_date = max(advanced_features['Date'])
         min_date = min(advanced_features['Date'])
@@ -453,6 +483,11 @@ class FeaturesAssembler(AbstractAssembler):
         print('Actual min feature date '+str(min_date))
         print('Actual starting date '+str(self.starting_date))
 
+        if self.backup_intermediary :
+            adv_feat_df_name = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y') + self.adv_feat_df_before_merge_suffix
+            print('saving '+adv_feat_df_name)
+            advanced_features.to_pickle(self.local_root_directory+adv_feat_df_name)
+
         df_ret=df_ret[df_ret.index>=self.starting_date]
         df_ret=df_ret[df_ret.index<=self.running_date]
 
@@ -515,6 +550,17 @@ class FeaturesAssembler(AbstractAssembler):
         print('number of nans in returns')
         print(np.isnan(df_ret[strats]).sum(axis=0))
 
+        if self.backup_intermediary :
+            short_feat_df_name = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y') + self.short_feat_df_suffix
+            adv_feat_df_name = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y') + self.adv_feat_df_suffix
+            ret_feat_df_name = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y') + self.ret_feat_df_suffix
+            print('saving '+short_feat_df_name)
+            df_ret[shortcut_features_names].to_pickle(self.local_root_directory+short_feat_df_name)
+            print('saving '+adv_feat_df_name)
+            df_ret[features_names].to_pickle(self.local_root_directory+adv_feat_df_name)
+            print('saving '+ret_feat_df_name)
+            df_ret[strat_features_names].to_pickle(self.local_root_directory+ret_feat_df_name)
+
 
         ret_df = df_ret[strats]
         ret = ret_df.values
