@@ -102,16 +102,18 @@ class SimpleExplainer(AbstractRunner):
         whole_history = (
                     feature_type is features_type.FeaturesType.HISTORY or feature_type is features_type.FeaturesType.HISTORY_ADVANCED)
 
-        features, features_names = self.dbx.local_features_npy_ovverwrite_and_load_array(starting_date=self.starting_date,
-                                                                                         ending_date=self.running_date,
-                                                                                         feature_type=feature_type,
-                                                                                         n_past_features=n_past_features,
-                                                                                         local_root_directory=self.local_root_directory,
-                                                                                         user=self.user,
-                                                                                         features_saving_suffix=self.features_saving_suffix,
-                                                                                         features_names_saving_suffix=self.features_names_saving_suffix,
-                                                                                         shortcut_features_pkl_file_name=self.shortcut_features_pkl_file_name)
+        features, features_names, shortcut_features, shortcut_features_names = self.dbx.local_features_npy_ovverwrite_and_load_array(starting_date= self.starting_date, ending_date = self.running_date,feature_type=feature_type, n_past_features=n_past_features,
+                                                    local_root_directory=self.local_root_directory, user=self.user,
+                                                    features_saving_suffix=self.features_saving_suffix,
+                                                    features_names_saving_suffix=self.features_names_saving_suffix,
+                                                    shortcut_features_saving_suffix=self.shortcut_features_saving_suffix,
+                                                    shortcut_features_names_saving_suffix=self.shortcut_features_names_saving_suffix)
 
+
+        assert shortcut_features.shape[0] == features.shape[0]
+
+        # the save files necessarily match the beginning date
+        shortcut_features = shortcut_features[:len(df)]
         features = features[:len(df)]
         result = result[:len(df)]
 
