@@ -35,7 +35,7 @@ class ForecasterParalleLauncher():
         self.key_args.sort()
         self.counter = 1
         for me_arg in self.key_args:
-            continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo = self.create_saving_key(*me_arg)
+            continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, _ = self.create_saving_key(*me_arg)
             self.mapping_keys[continuous_saving_key] = self.counter
             self.counter = self.counter + 1
             self.mapping_keys[two_states_saving_key] = self.counter
@@ -109,7 +109,7 @@ class ForecasterParalleLauncher():
         three_states_saving_key_lo = json.dumps(common_params, sort_keys=True)
         three_states_saving_key_lo = signal_utility.convert_to_sql_column_format(three_states_saving_key_lo)
 
-        return continuous_saving_key, two_states_saving_key, three_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo
+        return continuous_saving_key, two_states_saving_key, three_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, idios
 
     def launchParallelPool(self, toRun, use_num_cpu):
         with Pool(processes=use_num_cpu) as pool:
