@@ -35,9 +35,13 @@ class MixerParalleLauncher():
         self.key_args.sort()
         self.counter = 1
         for me_arg in self.key_args:
-            continuous_saving_key, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, _ = self.create_saving_key(*me_arg)
+            continuous_saving_key, continuous_saving_key_scale_one, continuous_saving_key_scale_two, two_states_saving_key, two_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, _ = self.create_saving_key(*me_arg)
             self.mapping_keys[continuous_saving_key] = self.counter
             self.counter = self.counter + 1
+            self.mapping_keys[continuous_saving_key_scale_one] = self.counter
+            self.counter = self.counter + 1
+            self.mapping_keys[continuous_saving_key_scale_two] = self.counter
+            self.counter = self.counter + 1
             self.mapping_keys[two_states_saving_key] = self.counter
             self.counter = self.counter + 1
             self.mapping_keys[two_states_saving_key_lo] = self.counter
@@ -109,7 +113,21 @@ class MixerParalleLauncher():
         three_states_saving_key_lo = json.dumps(common_params, sort_keys=True)
         three_states_saving_key_lo = signal_utility.convert_to_sql_column_format(three_states_saving_key_lo)
 
-        return continuous_saving_key, two_states_saving_key, three_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, idios
+        common_params.update({
+            'discretization': -1,
+            'type': 'long short'
+        })
+        continuous_saving_key_scale_one = json.dumps(common_params, sort_keys=True)
+        continuous_saving_key_scale_one = signal_utility.convert_to_sql_column_format(continuous_saving_key_scale_one)
+
+        common_params.update({
+            'discretization': -2,
+            'type': 'long short'
+        })
+        continuous_saving_key_scale_two = json.dumps(common_params, sort_keys=True)
+        continuous_saving_key_scale_two = signal_utility.convert_to_sql_column_format(continuous_saving_key_scale_two)
+
+        return continuous_saving_key, continuous_saving_key_scale_one, continuous_saving_key_scale_two, two_states_saving_key, three_states_saving_key_lo, three_states_saving_key, three_states_saving_key_lo, idios
 
     def launchParallelPool(self, toRun, use_num_cpu):
         with Pool(processes=use_num_cpu) as pool:
