@@ -698,7 +698,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print(str(len(y_train_true)))
         print(str(len(y_train_pred)))
         splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(y_train_pred, y_train_true)
-        y_next_pred = local_signal_df.values[prediction_index, :].nanmean()
+        y_next_pred = np.nanmean(local_signal_df.values[prediction_index, :])
         print('day continuous prediction ' + str(y_next_pred))
         y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
         print('day discrete prediction ' + str(y_next_pred_discrete))
@@ -721,7 +721,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         print(str(len(y_train_true)))
         print(str(len(y_train_pred)))
         splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(y_train_pred, y_train_true)
-        y_next_pred = local_signal_df.values[prediction_index, :].nanmean()
+        y_next_pred = np.nanmean(local_signal_df.values[prediction_index, :])
         print('minute continuous prediction '+str(y_next_pred))
         y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
         print('minute discrete prediction '+str(y_next_pred_discrete))
@@ -741,7 +741,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
             y_train_pred = np.mean(rolling_np, axis=1)
             splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(
                 y_train_pred, y_train_true)
-            y_next_pred = signals_np[row_index, :].nanmean()
+            y_next_pred = np.nanmean(signals_np[row_index, :])
             y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
             y_pred_discretized[prediction] = y_next_pred_discrete
         return y_pred_discretized
@@ -760,7 +760,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
             y_train_pred = np.mean(rolling_np, axis=1)
             splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(
                 y_train_pred, y_train_true)
-            y_next_pred = signals_np[row_index, :].nanmean()
+            y_next_pred = np.nanmean(signals_np[row_index, :])
             y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
             y_pred_discretized[prediction] = y_next_pred_discrete
         return y_pred_discretized
